@@ -5,7 +5,7 @@ use Package::Rename qw(link_package);
 
 link_package "Lingua::ID::Number::Format::MixWithWords", "MixWithWords::ID";
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 1;
 # ABSTRACT: Alias for Lingua::ID::Number::Format::MixWithWords
 
@@ -13,7 +13,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -21,28 +21,15 @@ MixWithWords::ID - Alias for Lingua::ID::Number::Format::MixWithWords
 
 =head1 VERSION
 
-version 0.05
-
-=head1 AUTHOR
-
-Steven Haryanto <stevenharyanto@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by Steven Haryanto.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 DESCRIPTION
+This document describes version 0.06 of MixWithWords::ID (from Perl distribution Lingua-ID-Number-Format-MixWithWords), released on 2015-09-03.
 
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 format_number_mix(%args) -> any
 
+Format number to a mixture of numbers and words (e.g. "12,3 juta").
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -55,8 +42,8 @@ Number must be larger than this to be formatted as mixture of number and word.
 
 Whether smaller number can be formatted with 0,x.
 
-If minI<fraction is 1 (the default) or 0.9, 800000 won't be formatted as 0.9
-omillion but will be if min>fraction is 0.8.
+If min_fraction is 1 (the default) or 0.9, 800000 won't be formatted as 0.9
+omillion but will be if min_fraction is 0.8.
 
 =item * B<num> => I<float>
 
@@ -70,6 +57,33 @@ Can be negative, e.g. -1 to round to nearest 10, -2 to nearest 100, and so on.
 
 =back
 
-Return value:
+Return value:  (any)
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Lingua-ID-Number-Format-MixWithWords>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/perlancar/perl-Lingua-ID-Number-Format-MixWithWords>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Lingua-ID-Number-Format-MixWithWords>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2015 by perlancar@cpan.org.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
